<?php

namespace Litepci\Notification\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepci\Notification\Interfaces\NotificationRepositoryInterface;

class NotificationPublicController extends BaseController
{
    // use NotificationWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepci\Notification\Interfaces\NotificationRepositoryInterface $notification
     *
     * @return type
     */
    public function __construct(NotificationRepositoryInterface $notification)
    {
        $this->repository = $notification;
        parent::__construct();
    }

    /**
     * Show notification's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $notifications = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$notification::$notification.names'))
            ->view('$notification::public.notification.index')
            ->data(compact('$notifications'))
            ->output();
    }

    /**
     * Show notification's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $notifications = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$notification::$notification.names'))
            ->view('$notification::public.notification.index')
            ->data(compact('$notifications'))
            ->output();
    }

    /**
     * Show notification.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $notification = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$notification->name . trans('$notification::$notification.name'))
            ->view('$notification::public.notification.show')
            ->data(compact('$notification'))
            ->output();
    }

}
